import http from 'http';
import https from 'https';
const parse = (url) => {
    const _url = new URL(url);
    const request = _url.protocol === 'http:' ? http.request : https.request;
    return [_url, request];
};
export function post(url, data, headers) {
    const [_url, request] = parse(url);
    return new Promise((resolve, reject) => {
        const req = request(_url, {
            method: 'POST',
            headers: { ...data.getHeaders(), ...headers },
            ...this,
        });
        req.on('error', reject);
        req.on('response', res => {
            if (res.statusCode === 200) {
                resolve(res);
            }
            else {
                res.resume();
                reject(new Error(res.statusCode + ' ' + res.statusMessage));
            }
        });
        data.pipe(req);
    });
}
export function get(url) {
    const [_url, request] = parse(url);
    return new Promise((resolve, reject) => {
        const req = request(_url, {
            method: 'GET',
            ...this,
        });
        req.on('error', reject);
        req.on('response', res => {
            if (res.statusCode === 200) {
                resolve(res);
            }
            else {
                res.resume();
                reject(new Error(res.statusCode + ' ' + res.statusMessage));
            }
        });
        req.end();
    });
}
const client = (config) => ({
    post: post.bind(config || null),
    get: get.bind(config || null),
});
export default client;
